package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````?!T```````!``````````-"3````
M````!0```$``.``(`$``%``3``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````#``!P
M!````-R2`````````````````````````````$H````````````````````!
M``````````$````%````````````````````````````````````[(0`````
M``#LA``````````0`````````0````8````0C@```````!">````````$)X`
M``````"8!````````/`$`````````!`````````"````!@```"".````````
M()X````````@G@```````.`!````````X`$````````(`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````0C@```````!">````````$)X```````#P`0``````
M`/`!`````````0`````````O;&EB+VQD+6UU<VPM<FES8W8V-"YS;RXQ````
M`````!$```!,````!`````@````@D!``!4`$@"@`$02`A@2$@@$```D`!`B(
M@!!!N@`"B`````!,````3P```%(```!3````60```%H```!;````70```%X`
M``!?````80```&(```!C````90``````````````:G^:?,[>1RUOQ=\?+L6;
MMM1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!N^.2?%7#/-)GK\QF
MB`=PTT-%U>QS4)_8,V+;[12,)<P_S])L_V'R87^IG)O@IP(*:QJ>4*/@^TD`
M``````````````````````````````````````````,`"`!`'```````````
M`````````0```!(`````````````````````````"0```!(`````````````
M````````````$````!$`````````````````````````UP$``!$`````````
M````````````````9@$``!(`````````````````````````%P```!(`````
M````````````````````M@$``!(`````````````````````````'P```!(`
M````````````````````````)@```!(`````````````````````````TP(`
M`"(`````````````````````````Y`$``!(`````````````````````````
MP@$``!(`````````````````````````+P```"``````````````````````
M````[0(``"$`````````````````````````1P```!(`````````````````
M````````30```!(`````````````````````````5````!(`````````````
M````````````G@(``!(`````````````````````````O`(``!(`````````
M````````````````6P```!(`````````````````````````_P$``!(`````
M````````````````````8@```!(`````````````````````````A0(``!(`
M````````````````````````:0```!(`````````````````````````<0``
M`!(`````````````````````````EP(``!(`````````````````````````
M>0```!(`````````````````````````;@(``!(`````````````````````
M````@0```!(`````````````````````````AP```!(`````````````````
M````````D````"``````````````````````````^P,``"(`````````````
M````````````K@(``!(`````````````````````````K````!(`````````
M````````````````L0```!(`````````````````````````@P$``!8`````
M````````````````````C`(``!(`````````````````````````+`(``!(`
M````````````````````````N````!(`````````````````````````'@(`
M`!(`````````````````````````,P,``!(`````````````````````````
M[`(``!$`````````````````````````4`(``!(`````````````````````
M````V0(``!(`````````````````````````[@(``!$`````````````````
M````````OP```!(`````````````````````````R````!$`````````````
M````````````=`$``!(`````````````````````````V@```"(`````````
M````````````````Z0```"``````````````````````````_P```!(`````
M````````````````````RP(``!(`````````````````````````/`(``!(`
M````````````````````````!`$``"``````````````````````````>0(`
M`!(`````````````````````````'@$``!(`````````````````````````
MIP$``!(`````````````````````````(P$``!(`````````````````````
M````7@(``!(`````````````````````````E@$``!(`````````````````
M````````*0$``!(`````````````````````````.@$``!(`````````````
M````````````^@$``!(`````````````````````````@@```!(`````````
M````````````````"P(``!(`````````````````````````10(``!(`````
M````````````````````M0(``!(`````````````````````````I@(``!(`
M````````````````````````0`$``!(`````````````````````````]0$`
M`!(`````````````````````````1P$``!(`````````````````````````
M3@$``!(`````````````````````````ZP(``"$`````````````````````
M````7P$``!(`````````````````````````Y@(``!(`"`!`'````````#P!
M````````D0,``!(`"``L*0```````!P$````````3`0``!(`"`#0+@``````
M`$P`````````4@,``!(`"`"<)`````````(`````````M`,``!(`"`!(+0``
M`````(@!````````(00``!(`"`">)````````*0!````````[`,``!``$`"H
MH@``````````````````?P,``!(`"`"N*````````'X`````````G@,``!(`
M"``D(P```````"8`````````I@,``!(`"`!L*````````"H`````````R@,`
M`!(`"`!N0`````````P!````````WP,``!(`"`!")@```````"(`````````
M1P0``!``$```HP``````````````````&`,``!(`"`"4'0```````"(`````
M`````00``!(`"`!D)@```````/X`````````U0,``!$`#@!(H`````````@`
M````````&@0``!``#P"HH@``````````````````;P,``!``#P"HH@``````
M````````````\0,``!(`"`!\'0``````````````````^`,``!(`"``:0```
M`````%0`````````.`0``!``#@``H```````````````````8P,``!``$```
MHP``````````````````(0,``!(`"`"6*````````!@`````````/`,``!(`
M"`",(P```````!`!````````+@0``!(`"`!Z00```````'@!````````#00`
M`!(`"`!B)P````````H!`````````&]P96YD:7(`;65M8VUP`'-T9&5R<@!R
M96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF
M;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S
M=')N8VUP`'-T<G)C:'(`;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7W-T
M86-K7V-H:U]G=6%R9`!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE
M7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD
M:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!M96UC<'D`<W1R;&5N`%]?<W1A
M8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C
M;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`<W1R8W!Y`')E861D:7(`<W!R:6YT9@!S=')D=7``<W1R=&]K
M`'!T:')E861?871F;W)K`&9P<FEN=&8`7V9I;FD`7U]L:6)C7W-T87)T7VUA
M:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UR:7-C=C8T+G-O
M+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`7U]"4U-?14Y$7U\`
M7U]31$%405]"14=)3E]?`'!A<E]S971U<%]L:6)P871H`'!A<E]M:W1M<&1I
M<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R
M=`!S:&%?:6YI=`!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A`'!A
M<E]F:6YD<')O9P!S:&%?9FEN86P`7U]$051!7T)%1TE.7U\`7V5N9`!P87)?
M8VQE86YU<``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210```!">````
M`````P````````!2'@```````!B>`````````P`````````$'@````````"@
M`````````P``````````H````````!B@`````````P````````!(1```````
M`""@`````````P````````"`1@```````"B@`````````P````````"(1@``
M`````#"@`````````P````````"01@```````#B@`````````P````````"8
M1@```````$B@`````````P````````"@1@```````"BB`````````P``````
M``!`'````````#"B`````````@````0``````````````#BB`````````@``
M``4``````````````$"B`````````@````L``````````````$BB````````
M`@````X``````````````%"B`````````@```"```````````````%BB````
M`````@```"$``````````````&"B````````"P```"4``````````````&BB
M`````````@```"X``````````````'"B`````````@```#``````````````
M`'BB`````````@```#(``````````````("B`````````@```#,`````````
M`````(BB`````````@```#<``````````````)"B`````````@```#P`````
M`````````)BB`````````@```#T``````````````*"B`````````@```$(`
M`````````````&"@````````!0````(``````````````&B@````````!0``
M``,``````````````'"@````````!0````8``````````````'B@````````
M!0````<``````````````("@````````!0````@``````````````(B@````
M````!0````D``````````````)"@````````!0````H``````````````)B@
M````````!0````P``````````````*"@````````!0````T`````````````
M`*B@````````!0```!```````````````+"@````````!0```!$`````````
M`````+B@````````!0```!(``````````````,"@````````!0```!,`````
M`````````,B@````````!0```!0``````````````-"@````````!0```!4`
M`````````````-B@````````!0```!8``````````````."@````````!0``
M`!<``````````````.B@````````!0```!@``````````````/"@````````
M!0```!D``````````````/B@````````!0```!H```````````````"A````
M````!0```!L```````````````BA````````!0```!P``````````````!"A
M````````!0```!T``````````````!BA````````!0```!X`````````````
M`""A````````!0```!\``````````````"BA````````!0```"(`````````
M`````#"A````````!0```",``````````````#BA````````!0```"0`````
M`````````$"A````````!0```"8``````````````$BA````````!0```"<`
M`````````````%"A````````!0```"@``````````````%BA````````!0``
M`"D``````````````&"A````````!0```"H``````````````&BA````````
M!0```"P``````````````'"A````````!0```"T``````````````'BA````
M````!0```"\``````````````("A````````!0```#$``````````````(BA
M````````!0```#0``````````````)"A````````!0```#4`````````````
M`)BA````````!0```#8``````````````*"A````````!0```#@`````````
M`````*BA````````!0```#D``````````````+"A````````!0```#H`````
M`````````+BA````````!0```#L``````````````,"A````````!0```#X`
M`````````````,BA````````!0```#\``````````````-"A````````!0``
M`$```````````````-BA````````!0```$$``````````````."A````````
M!0```$,``````````````.BA````````!0```$0``````````````/"A````
M````!0```$4``````````````/BA````````!0```$8```````````````"B
M````````!0```$<```````````````BB````````!0```$@`````````````
M`!"B````````!0```$D``````````````!BB````````!0```$L`````````
M`````)>#```S`\-!`[X#>Q,#0_V3@@-[$U,3`(.R@@!G``X`%XX```,^#GIG
M`PX`$P```!>.```#/HYY9P,.`!,````7C@```SX.>6<##@`3````%XX```,^
MCGAG`PX`$P```!>.```#/@YX9P,.`!,````7C@```SZ.=V<##@`3````%XX`
M``,^#G=G`PX`$P```!>.```#/HYV9P,.`!,````7C@```SX.=F<##@`3````
M%XX```,^CG5G`PX`$P```!>.```#/@YU9P,.`!,````7C@```SZ.=&<##@`3
M````%XX```,^#G1G`PX`$P```!>.```#/HYS9P,.`!,````7C@```SX.<V<#
M#@`3````%XX```,^CG)G`PX`$P```!>.```#/@YR9P,.`!,````7C@```SZ.
M<6<##@`3````%XX```,^#G%G`PX`$P```!>.```#/HYP9P,.`!,````7C@``
M`SX.<&<##@`3````%XX```,^CF]G`PX`$P```!>.```#/@YO9P,.`!,````7
MC@```SZ.;F<##@`3````%XX```,^#FYG`PX`$P```!>.```#/HYM9P,.`!,`
M```7C@```SX.;6<##@`3````%XX```,^CFQG`PX`$P```!>.```#/@YL9P,.
M`!,````7C@```SZ.:V<##@`3````%XX```,^#FMG`PX`$P```!>.```#/HYJ
M9P,.`!,````7C@```SX.:F<##@`3````%XX```,^CFEG`PX`$P```!>.```#
M/@YI9P,.`!,````7C@```SZ.:&<##@`3````%XX```,^#FAG`PX`$P```!>.
M```#/HYG9P,.`!,````7C@```SX.9V<##@`3````%XX```,^CF9G`PX`$P``
M`!>.```#/@YF9P,.`!,````7C@```SZ.96<##@`3````%XX```,^#F5G`PX`
M$P```!>.```#/HYD9P,.`!,````7C@```SX.9&<##@`3````%XX```,^CF-G
M`PX`$P```!>.```#/@YC9P,.`!,````7C@```SZ.8F<##@`3````%XX```,^
M#F)G`PX`$P```!>.```#/HYA9P,.`!,````7C@```SX.86<##@`3````%XX`
M``,^CF!G`PX`$P```!>.```#/@Y@9P,.`!,````7C@```SZ.7V<##@`3````
M%XX```,^#E]G`PX`$P```!>.```#/HY>9P,.`!,````Y<2[H,N0JSC``#`AH
M"`;\(O@F]._PW^H7A@```S:&9+*%%X4```,U96/O\'_2EX<``(.WIUR#QP<`
MEX0``(.T9%X7A```$P3D98WC[_!?WPCL`>4%1>_PO^?O\'_LLX=$`)QC!6>Z
MEZ.+!Z22E)A@<D6#1Z=*&P8U`!$ED^<W`",%]TH.!3+@[_"?YZJ&".1"97)(
M`F8<80%'G.*7-P``DX='F9SFEX<``(.W)S:<ZI<W``"3AX>8G.Z;!T<`!0>.
M!YL%!P"VEV/$!0<(;".P!P`!1Y<%``"3A65C[_!?T*J$">4(;._PO^"JA`AL
M[_`_VA<E```3!65J[P!`'1'M'&B!ZQ<E```3!<5A[P`@'`CH"&@9P>\0H!<(
M;._P7^KO\!^XXG!"=":%HG0A88*`DQ4W`*J5C&&,XT&WEY$``).!0:@*A9>%
M``"3A:4)$W$!_PF@#$$3!H4`@4<7AP```S='2I>&``"#MD9+%X4```,UQ4<U
MLQ>%```3!:4IEX<``).')RECB*<`EX<``(.W9TB1PX*'@H`7A0``$P6%)Y>%
M``"3A04GB8V3US5`_9&^E86%F<67AP``@[<G29'#@H>"@$$1(N`7A```$P0$
M2H-'!``&Y)7KEX<``(.W!T:1QQ>%```#->4=@I?O\+_XEX<``(.WAT&1QQ=E
M```3!>5J@I>%1R,`]`"B8`)D00&"@)>'``"#M^="F<]!$0;DEX4``).%!447
M90``$P4%:(*7HF!!`8VWA;<Y<2;T!OPB^$KP3NQ2Z%;D6N"!1#G-EX<``(.W
MAST#N@<`@41C!PH$JHFNBBJ&$P?0`X-'!@"IZSL$-D%2B1,+T`.#-`D`E<0B
MALZ%)H7O\)^R'>VSAX0`@\<'`&.:9P,S"4E!$UDY0!,&%``CH"H!LI3B<$)T
M`GGB:4)JHFH":R:%HG0A88*`XXCG^@4&5;<A"46_`1$BZ`;L%X0```,TQ#4<
M8#[D@4=,`._P?_4B9QQ@N8\!1YG#[_#_SN)@0F0%88*`.7$B^";T2O!.[`;\
MEX0``(.T9#(JA)Q@/N2!1Q,)00"7B0``@[FI,,J%(H7O\!_Q`>DB9YQ@N8\!
M1XG/[_!_RA)'@[<)``X'NI>89YCC:=^A!^6_XG!"=*)T`GGB:2%A@H!Q<2+Q
M)NT&]9>$``"#M(0LG&`^Y8%'+``JA._P?Z<=Y>)'/6?YCQ%G8X7G`"EG8YCG
M`(E%(H7O\+^3$S45`"IGG&"YCP%'B<?O\)_#`47%OZIP"G3J9$UA@H!5<5+Q
MAN6BX2;]2OE.]5;M6ND7B@```SI*)H,W"@`^Y8%'!<V#1P4`JH2%R^_POXFJ
MB07%ERH``).*JBP7*P``$PNK+$Z%[_`?E"J$&>U.A>_P?Y\FA>_P'[(J9X,W
M"@"YCP%'O<OO\!^\3036A2*%[_!_D&'9VH4BA>_PWX]YT2:%[_!?N2J)(H7O
M\-^X.P6I``DE[_`_E**&)H:7)0``DX4E)RJ)[_`?M"P`2H7O\)^P_5=C#_4`
MXD<]9_F/$6=CF><`2H7O\+_S2H7O\+^ME;]*A>_P/X_-OZY@#F3J=$IYJGD*
M>NIJ2FMI88*`'7&BZ,%R062FY,K@3OQ2^%;T6O!>[&+HANP3!X0`%I$*EQ>*
M```#.FH6@S<*`!SC@4<)1H%%JHGO\!^#DP3U_T%FL^?$`D%[$PD+_Y,*A@"=
M2Q>,```3#.SLG8R3!P0!RI<SB2<`8]0$`'U5-:@!1J:%3H7O\$__5H;*A4Z%
M[_"_GAL$!0!C]HL`811*E&-T)`':E,F_(4;BA2*%[_#/]!GM,P4D02:5P6>A
M!XJ7F&.#-PH`N8\!1XG'[_#_IWT4^;?!8A:1YF!&9*9D!FGB>4)ZHGH">^)K
M0FPE88*`'7&BZ*;D4OB&[,K@3OQ6]%KP7NP7B@```SIJ"0/'!0"#-PH`/N2!
M1Y,'T`.JA"Z$8Q3W`!.$%0`BA>_P'Z$JB4P`)H7O\!_'JHD%Q>_P_Y]C8R4'
M@T<$``4$A0FCC_G^]?LB9X,W"@"YCP%'\<_O\-^>EXH``(.Z"@.#NPH`@4G>
MAYAC4>^7AP``DX='"9A#FX4I`(X%0<M>A>_P#^DCL*H`8=&#MPH`&X<9``X'
MNI<CL`<`3L(FA1,'T`.#1P4`F<-CD><(DDD7BP```SNK_8,Z"P`%G0D)C@E*
ME<Z:[_#/\B.PJ@`UW8,W"P`3!M`#SI><8P/'!`"%!+Z&(X#G`(4'&</C&,?^
M$P?0`R.`Y@`#1P0`!02%!Z./Y_YU^Y&WH0>%*;F_!4<NA9C#[_#O[2J+!=D3
MECD`WH7O\`_N([!J`8VW!06=O^9@1F2F9`9IXGE">J)Z`GOB:R5A@H"7AP``
M@[?'\Y=F``"3AL89%X8```,VQO62EXACER4``).%!?VEN$$1(N`7A````S0D
M\0;DLP=$`(AC[_!__!*4"&`"9*)@%R<``!,'YR^!1[J&%Q8``!,&)IV7)0``
MDX4E^T$!;_"/VEUQ^7*&Y*+@)OQ*^`ED%I$3!X0!'`@^EY>$``"#M,3LG&`<
MXX%'[_#OVGEY(1F3!P0"RI<8"#.)YP`%9*J&%R<``!,'Y_<7)@``$P;F]Y,%
M%`!*A>_P#]3]5V,>]0"!1PEG%`AA!S:7%&.88#6/@499Q^_P/X)C<Z0``I!]
M=(EG0123AP<"HI<8"#.$YP`%9J*%2H7O\`_M&P8%`.-!!OP;!18`,N3O\._9
MJH=-V2)F,PG%`&-TA0#C823]?7>)9D$7DX8&`KJ6&`@VEV-U]P`RE^/DY_H%
M9P4'XT#'^OUU"6?!%1,'!P(NEQ0(/H6S!=<`[_`O]ZJ'(P`)`)6WB6(6D:9@
M!F3B=$)Y/H5A88*`Q;U1<?URA6>B\:;MTN%:^8;URNG.Y5;]7O5B\6;M$X>'
M"!:1"I<7BP```SOKVJJ$@S<+`!SC@4<7)0``$P7%Z"Z$[_`?HRJ*DP7P`B:%
M[_!OVPW%IH47)0``$P7EY^_PW\R%9Y.'APB*EYAC@S<+`+F/`4=CB0<0[_#/
M\"*%[_!OTY<E``"3A27F[_"OZH5G_7D3B8G_$X<'"4J7DXF)]S,))P`3AP<)
MDX<'"85J3I>*ERJ$ERL``).+B]JS"2<`,XQ704'8@T<$`)'C7H1C!PH`HH52
MA>_P[[])S2*%[_!OZ9,']?^BEQ,'\`)C=O0`@\8'`&./Y@(BA>_PK^>JC":%
M[_`OYZJ<A0SC]5SUIH<7)P``$P?'W:*&%R8``!,&IMV%94J%[_#OM04E8_>J
M``*0(X`'`/T75;_.A4J%[_!OW0WI@R>,^#UG^8\A9V.3YP*%14J%[_#OL0GM
MRH47)0``$P5EU^_P7[Q*A>_PC\2JA,6]ER4``).%!=<!1>_P;]LJA(&WA6(6
MD:YP)H4.=.YD3FFN:0YJZGI*>ZI["GSJ;&UA@H!!$9,%\`(BX`;D*H3O\"^\
M&<$3!!4`(H4"9*)@00%O\`^_.7']<B;T!OPB^$KPA6<6D1.'AP`<")>$``"#
MM&2_/I><8!SC@4<!Q8-'!0"![X5G&`BA![J7F&.<8+F/`4?-P^_PS]<JY._P
M;]8%!85G8^:G"GUT813!!Z*7&`BB93.$YP`BA>_PC[,BA>_P+]1]%2*5DP?P
M`F-VI``#1P4`8PWW!'UTA6=A%,$'HI<8"#.)YP"3!?`"2H7O\$^Q2=EC=*D`
M(P`%`(5GP0>BEQ@(,X7G`._PK[.%9Q@(H0>ZEYACG&"YCP%'K?^%8A:1XG!"
M=*)T`GDA88*`(P`%`'T58;^%8A:1XG!"=*)T`GD7)0``$P6%NB%A;_!OKP%%
M;;]!$1<E```3!47#!N3O\`_]%R4``!,%9</O\$_\%R4``!,%)</O\(_[%R4`
M`!,%9</O\,_Z%R4``!,%)</O\`_Z%R4``!,%9</O\$_Y%R4``!,%);OO\(_X
M%R4``!,%Y<+O\,_W%R4``!,%)</O\`_W%R4``!,%9</O\$_V%R4``!,%);GO
M\(_U%R4``!,%Y<+O\,_Q`<FJA1<E```3!>6_[_!?G!<E```3!:7"[_`/\*J%
M&<47)0``$P4EP^_PGYH7)0``$P5EP^_P3^ZJA1<E```3!06SB>T7)0``$P7E
MPN_PS^RJA1G%%R4``!,%Y;GO\%^7HF"7)0``DX6%PA<E```3!86V00&QND$1
M%R4``!,%I;<&Y._P;^FJAP%%@<N#QP<`B<>3AP?],S7P`*)@00&"@$$1!N3O
M\&^Y`27O\`^B$<$(8:)@00&"@`$1(N@JA!<E```3!46]!NPFY$K@[_#/Y**%
M"<6#1P4`JH29ZT)DXF"B9`)I%R4``!,%Y;H%8<VP[_"OF!WI(H7O\"^R*HDF
MA>_PK[%*E0D%[_`OC9<E``"3A>6H)H>7)@``DX9&IR*&*HGO\(^LRH55O^)@
M0F2B9`)I!6&"@`EQRO+.[M+JAOZB^J;VUN;:XE[^8OH7B@```SKJDH,W"@`^
M]H%'ER<``).'Y[03"0$$/NBJB9<G``"3AV>9$P8``Y=U``"3A:5J2H4^[`+P
M[_!/IY<G``"3AX>R/O07)0``$P5EG9<G``"3A^>Q/O@"_._P#]<-S8-'!0`J
MA(W+[_`_\#)W@S<*`+F/`4>9P^_P3Z8BA59T]G"V=!9Y]FE6:K9J%FOR>U)\
M&6%O\(^'[_"_ZRJ$)!!C!@40(H7O\&^B!@4%!>_@__VJBJJ$%RL``!,+:ZP#
M1@0`8Q0&$`,T"0`=P"*%[_#/SRJ$8P(%$(-'!0!CC@<.[_#/UV,*!0XBA>_P
M+X(JA`0(">@#N00`8PT)#H-'"0!CG@<,(H7O\&^<*HE6A>_P[YL[":D`&PE)
M0$J%[^`?]]:'%R<``!,')Z:7)@``DX:FD2*&ER4``).%A:6JA._P[Y63!0`<
M)H7O\$^0_5=C%/4*[_"OCAA!Q4=C#O<(EW<``(.WYW@#M@D`B&.FAI<E``"3
MA>6B[_!OA@%$,G>#-PH`N8\!1^.9!^[V<"*%5G2V=!9Y]FE6:K9J%FOR>U)\
M&6&"@._P;\()Z:$$B&!]^1<D```3!$2:];6#1P4`]=?OX-_T*H1UT?&])H7:
MA>_P[XP%!(D$Y;4A"?6U2H7O\._'H03C"`7P2H7OX#_R*H0)MP%$`;^,&":%
M[^`_[RJ+&>6*1SUG^8\19V.!YP*7=P``@[?G;0.V"0"(8Z:&ER4``).%Y9OO
MX'_[@;\J1._P[XL!)>,=I/R*1Q,'`!R3]_<?XY;G_$J%[^!?Y"J$%R4``!,%
M99[O\$^WJH5C&`40@[H)`%:%[_!OAAL)!0"-1V/;)P43!<G_ER4``).%19Q6
ME>_@O]HAX9%'8PKY`&TY5ID#1PD`DP?P`F,6]P(#N8D`8P()`DJ%[_!/@HU'
M8_RG`'$5ER4``).%!9E*E>_@_]81X<J*[_`_QDWI@456A>_@W^0JB5W![_#/
MS*J)8T\%"),%9?\!1DJ%[^`_TI,*`0\91M:%2H7OX%_Q&4:790``DX5EB5:%
M[^!?R"7I`4:3A>G\2H7OX'_/N!FZA1,&@`)*A3KD[^!_[B)GER<``).'AY^7
M%@``DX8&<2:&ER4``).%Y9`BA2,``1+OX!_U)H7OX+_PHH47%0``$P5%;._P
M+](BA>_P7\`)O0.U"0#O\*_^JHKC%P7NW;67%0``DX4%?!<5```3!05R[_!O
MS^_@W\@JAY<G``"3A^>8EQ8``).&9FHFAI<E``"3A46+(H7OX+_N_5E%29<J
M``"3BJJ6EQL``).+*V@7+```$PPLBI,%`!PBA>_@7^?C&C7W[^#?Y1Q!XY4G
M]^_@/\,%*RJ'5HC:A]Z&)H;BA2*%[^#_Z<&_>7$B\!=T```#-$11!O0F[$KH
M3N2S!T0`G&,7%0``$P5E9@/'!PNCB.<*[_#/F1')`T<%`),'$`-C%?<`@T<5
M`)G#[_"?G;,'1`"(8XU&!4:7)0``DX4%@^_@'\^JA!W%&&FS!T0`B&,,8Q<F
M```3!N:![^!_SYQHC&/<1=F#A8N1Q[,'1`"(8^_@'[ZS!T0`B&.-1@5&EQ4`
M`).%I7_OX+_*JHF7=```DX1$3S'!%Q4``!,%I5?O\`^1*H81R0.W"0&S!T0`
M#&.(8^_@_\D-H._P3]<#MPD!*HFS!T0`)<4JA@QCB&/OX#_(2H7OX-_6LP=$
M``.Y!P`%1I<5``"3A>5Y2H7OX%^KJH47%@``$P9F>DJ%[^!?Q1*4'&`7%0``
M$P7%3Z.(!PKO\.^)B.@9[8AD[_`_JXCH$>D7%0``$P7E=^_@?ZN49)!BM;^(
M:),%`!SOX'_/&P<5`(5'JH9C_N<`Q4=C"_4`G&20:!<5```3!45WC&/OX#^H
MHG`"=.)D0FFB:45A@H`!$0;L(N@FY"J$[_"O^._P3_:JA._PGY@-Q07$@T<$
M`(W#EQ4``).%95TFA>_@7[=CF:0`(H5"9.)@HF0%86_PSX[B8$)DHF0%88*`
M$P$!U!=^```#/@XU.`#]6$%C(SP1*B,X@2HC-)$J(S`A*R,\,2DC.$$I@S<.
M`",T\2B!1Y,%A0,3#X4'.HB3V`@"MP[_`!,#`_"48:$%00B3EX8!$Y:&`#-V
MU@&S]Q<!T8\3UH8`,W9F`-&/&]:&`=&/(SCX_I/7A@(3U@8"L_=G`.&2U8^3
M%H8!L_86`2(&U8\S=M8!T8\C//C^XQ>_^OU7DP4'((&3,&,T=R$'L8X09[&.
M`S:'_[&.$Y86`/V"T8[]CC3_XQ&W_@,_!0"#/@4"MX^"6I-6OP$3%U\`58^B
M9I./GYD#.`4!@SB%`0,SA0#^EGV/]I8VE[-&&`&S]F8`L\86`3:7DQ7C`9-6
M(P#5C4)FL_+U`+-&6`"S]N8!?I9]CT:6L\8&`9-3MP&REA,65P`S9G8`LI:S
M]/8`$Q;O`9-6+P!5CK/&Q0#B9?F.L\96`/Z5PI43U+0!KI:3E50`P8VNEC/Y
M]@"3%N<!"8/9C@)WLW/V`#6.98Y^EQ:7,T9V`)-5N0$ZEA,760!-CSJ6HG43
ME^0!B8!%CS/T]@"YCK/V)@'^E7V.GI6ACI-2M@&NEI,55@"SY54`KI:S\_8`
MDQ7I`9-6*0#5C<)VLW3W`"V/<8_^EJ*6)8\3U+,!-I>3EE,`P8XVEY,6Y@$)
M@E6.XG:S\O4`L8VS]74`_I9]CZ:6L\55`)-4MP&VE9,65P#%CK:5AF23EN,!
MD],C`+/F=@`S=/8`-8[^E'F._8VFDB&.D]2U`1:6DY)5`+/BD@`6EJ9DDQ+G
M`0F#,^?B`+/S]@"YCOZ4[8Y]CB:4L\9V`)-4M@&BEA,45@!%C**6QF03E.4!
MB8'!C;-R]P`MC_Z4<8_]CJ:3,T=7`)/4M@$>EY.35@"SXY,`'I?F9),3Y@$)
M@C/FPP`S]/4`L8W^E/6-?8^FDJ&-DU2W`9:5DQ)7`+/BD@"6E89TDY+F`8F"
ML^;2`+-S]@`UCOZ4>8[]C2:4,T9V`)/4M0$BEA.450!%C"*6IG03%.<!"8-!
MC[/R]@"YCOZ4[8Y]CJ:3L\96`)-4M@&>EI,35@"SXY,`GI;&=).3Y0&)@;/E
MLP`S=/<`+8_^E'&/_8ZFDB&/D]2V`1:7DY)6`+/BD@`6E^9TDQ+F`0F",^;"
M`+/S]0"QC?Z4]8U]CR:4L\5U`)-4MP&BE1,45P!%C**5BF03E.8!B8+!CK-R
M]@`UCOZ4>8[]C::3,T96`)/4M0$>EI.350"SXY,`'I:S=/8`$Q;G`0F#48\J
M9C/T]@"YCNV.?I86EJ&.D]*T`;*6$Y94`#-F5@"REK/R]@`3EN4!RF:)@4V.
MLW/W`#&/98_^EJ*6,T=W`)/5L@$VEY.64@#-CC:7ZF63EN0!B8#%CC-Y]@`U
MCC-V5@#^E7V/GI4S1B8!+I:34[<!DQ57`+/E=0#]C;,$M@`*=I.5X@&3TB(`
ML^55`#/T]@"MCOF.?I:S\_0`2I:ACI/?LP&REA,9YP$3EE,`"8,S:>D`,V;V
M`2IW?8ZW_]ENDX\?NK*6,\8E`26.?I>S^?8`(I=]CCJ6D]*Y`1.760`S9U<`
M?8^S!.8`$Y;C`1/7(P"S8^8`2G8S1WD`_8U^EC6/,_KT`"Z6?8^S!N8`$U:Z
M`1,76@!1CWV/NI:3DND!:G>3V2D`L^(R`3/&4P`S>?D`?I<ECC/T]@!]CDJ7
M,I>35;0!$Q94`$V.?8XZEI,4Z@$.9Q-:*@"SY$0!L\62`+/S\P!^EZV.,WGV
M`/V.'I<VEY-5N0&3%ED`S8[]CKJ6+F>3%>0!"8#!C;/R\@!^EQ:7L\*T`#/&
MP@"S^?8`?8XREY/2N0$3EED`,V96`'V..I:3$ND!3F<362D`L^(B`;/#50#]
MC'Z7L\;3`#-T]@#]CB:7-I>34[0!DQ94`+/F=@#]CKJ6;F>3D^D!D]DI`+/C
M,P']C7Z7+I>SQ7(`+8XS^?8`?8XREY-5N0$3%ED`38Y]CCJ6#G>3%>0!"8#!
MC;/R\@!^EQ:7L\*S`+/&T@"S=/8`_8XVEY/2M`&3EE0`L^96`/V.NI8N=Y,2
MZ0$362D`L^(B`;/S\P!^EQZ7L\-5`#/&PP`S]/8`?8XREY-3M`$3%E0`,V9V
M`'V..I9.=Y.3Y`&)@+/CDP#]C7Z7+I>SQ7(`K8XS>?8`_8XVEY-5N0&3%ED`
MS8[]CKJ6;G>3%>0!"8#!C;/R\@!^EQ:7L\*S`#/&P@"S]/8`?8XREY/2M`$3
MEE0`,V96`'V..I829Y,2Z0$362D`L^(B`;/S\P!^EQZ7L\-5`+/&TP`S=/8`
M_8XVEY-3M`&3%E0`L^9V`/V.NI8R9Y.3Y`&)@+/CDP#]C7Z7+I>SQ7(`+8XS
M^?8`?8XREY-5N0$3%ED`38Y]CCJ64F>3%>0!"8#!C;/R\@!^EQ:7L\*S`+/&
MT@"S=/8`_8XVEY/2M`&3EE0`L^96`/V.NI9R9Y,2Z0$362D`L^(B`;/S\P!^
MEQZ7L\-5`#/&PP`S]/8`?8XREY-3M`$3%E0`,V9V`'V..I82=Y.3Y`&)@+/C
MDP#]C7Z7+I>SQ7(`K8XS>?8`_8XVEY-5N0&3%ED`S8[]CKJ6,G>3%>0!"8#!
MC;/R\@!^EQ:7L\*S`#/&P@"S]/8`?8XREY/2M`$3EE0`,V96`'V..I92=Y,2
MZ0$362D`L^(B`;/S\P!^EQZ7L\-5`+/&TP`S=/8`_8XVEY-3M`&3%E0`L^9V
M`/V.NI9R=Y.3Y`&)@+/CDP#]C7Z7+I>SQ7(`+8XS^?8`?8Z35;D!,I<3%ED`
M38XRE[-T]P`69Q,6Y`$)@$&.?I>SS\,`L_+R`+/&WP#]CA:7D]^T`3:7DY94
M`+/F]@&3$ND!$UDI`+/B(@$VES-T]P"S=?8`L_?R`#-F5@`S]_4`MF]ECK?V
MQB-9CHH&?5<!DY.&QLVVG[/SXP#^DQZ6DQ]4`)-3M`&S[W\`?I:3TR0`DY_D
M`;/O?P"S\^\`L^+R`;/T=P"S\H(`L^*2`-9D>8ZVE*:5KI*35+8!DQ56`,6-
MKI*3%>0!"8#!C;/TY0"S[[\`,_23`+/_SP"S[X\`=F2S\N(`-I2BE[Z?$]2R
M`9.74@#!C[Z?DQ?F`0F"78XS=.8`T8VS]X0`L_55`-V-EG>S_^\`MI>>E[Z5
MD]._`9.77P"SYW<`OI63E^(!D](B`+/G5P"S\^<`78ZS<G0`,W;V`3-F5@"V
M<OF-MI*FDA:6D]2U`9.250"SXI(`%I:3DN\!D]\O`+/O\@&S\N\`L^?W`;/T
M4P#MC\6/UG1YCK:4)I2BEY-4M@$3%%8`18RBEQ.4Y0&)@<&-,_3E`+/OOP"S
M]((`L__/`+/OGP#V=/F/MI2FDYZ?D]2W`9.35P"SXY,`GI^3$^8!"8(SYL,`
MLW/F`-&-LW1T`/V-Q8V:9+/_[P"VE*:2EI63U+\!DY)?`+/BD@"6E9.2YP&)
M@[/G\@"S\N<`78ZS]%,`,W;V`46.NF3YC;:4)I0BEI/4M0$3E%4`18PBEA.4
M[P&3WR\`LV_T`3/T[P"SY_<!L_2"`.V/Q8_:9'F.MI2FDYZ7DU2V`9,35@"S
MXY,`GI>3D^4!B8&SY;,`L_/E`+/OOP"S='0`L__/`+/OGP#Z9/F/MI2FDI:?
MD]2W`9.25P"SXI(`EI^3$N8!"8(SYL(`LW+F`-&-L_13`/V-Q8V:=+/_[P"V
ME":4HI63U+\!$Y1?`$6,HI43E.<!B8/!CS/TYP!=CK/T@@`S=O8!18ZZ=/F-
MMI2FDQZ6D]2U`9.350"SXY,`'I:3D^\!D]\O`+/O\P&S\^\`L^?W`;-T=`#M
MC\6/VG1YCK:4II*6EY-4M@&3$E8`L^*2`):7DY+E`8F!L^6R`+/RY0"S[[\`
ML_13`+/_SP"S[Y\`^G3YC[:4)I2BGY/4MP$3E%<`18RBGQ,4Y@$)@D&.LW3F
M`-&-,_22`/V-P8T>9+/_[P`VE**3GI43U+\!DY-?`+/C@P">E;/SY0"3E><!
MB8/-CS/TYP!=CK/UA``S=O8!38Z^9;:5EI4NEI/2LP&3E5,`L^55`"Z6DY7O
M`9/?+P"SY?4!,_GE`,V/LW+F`+/W=P`S=B0!T8]>9I/?L@$VEB:6LI<3EE(`
M,V;V`;*7$Y;C`9/3(P`S9G8`LW3F`-&-LW^9`+/U50"SY?4!_F_YCY/3MP&V
MGZ*?_I63GU<`L^]_`+/_[P#^E9.?X@&3TB(`L^]?`+/R[P`S9O8!,_14`'V.
M08X>=+/SY0"BELJ6-I83U+,!DY93`,&.^8X3E.<!B8.S"=8`78P^=K>WF#**
M!Y.'9QVSQH\`K8X^EC/YZ0`FEOF.DU6Y`;*6$Q99`$V.>8ZREI.5XP$3UB,`
ML^/%`-YU,T9T`#-&-@&^E;/TY@"6E7F.+I:3W[0!DY54`+/E]0'YC;,)M@"3
M%>D!$U8I`#/IQ0!^=K/%(P%YC#Z6K8ZS\ND`(I;YCK*6D]6R`1.64@!-CGF.
M,X3&`).5Y`&#-@$@B8#%C3-&N0"S\^,`OI8S1C8!LW_D`'F.GI:REI/3OP$3
MEE\`,V9V`'F.LXG&`).3X@&#-H$@D](B`+/C4P`SQG4`,WGI`+Z6(8ZS].D`
M>8[*EK*6D]*T`1.65``S9E8`>8XVEH,V`2&3DN\!D]\O`+/B\@'YC;Z6KI:S
MQ5,`L\4U`3-TY@#YC:Z6DU^T`9,55`"SY?4!^8VVE8,V@2&3G^0!B8"S[Y\`
ML_/C`+Z6GI:SP_(!,\;#`#/YY0!YCK*6DU.Y`1,660`S9G8`>8XVEH,V`2*3
M$^0!"8"SXX,`L_+B`+Z6EI:SPG\`L\6R`+-TY@#YC:Z6D]*T`9.55`"SY54`
M^8VVE8,V@2*3$ND!$UDI`+/B(@&S_^\`OI;^EK//4P`SQL\`,_3E`'F.LI:3
M7[0!$Q94`#-F]@%YCC:6@S8!(Y.?Y`&)@+/OGP"S\^,`OI:>EK/#\@&SQ;,`
M,WGF`/F-KI:34[D!DQ59`+/E=0#YC;:5@S:!(Y,3Y`$)@+/C@P"S\N(`OI:6
MEK/"?P`SQL(`L_3E`'F.LI:3TK0!$Y94`#-F5@!YCC:6@S8!)),2Z0$362D`
ML^(B`;/_[P"^EOZ6L\]3`+/%OP`S=.8`^8VNEI-?M`&3%50`L^7U`?F-MI6#
M-H$DDY_D`8F`L^^?`+/SXP"^EIZ6L\/R`3/&PP`S^>4`>8ZREI-3N0$3%ED`
M,V9V`'F.-I:#-@$EDQ/D`0F`L^.#`+/RX@"^EI:6L\)_`+/%L@"S=.8`^8VN
MEI/2M`&3E50`L^55`/F-MI6#-H$EDQ+I`1-9*0"SXB(!L__O`+Z6_I:SSU,`
M,\;/`#/TY0!YCK*6DU^T`1,65``S9O8!>8XVEH,V`2:3G^0!B8"S[Y\`L_/C
M`+Z6GI:SP_(!L\6S`+-YY@#YC:Z6D].Y`9.560"SY74`^8VVE8,V@2:3$^0!
M"8"SXX,`L_+B`+Z6EI:SPG\`,\;"`#/YY0!YCK*6DU*Y`1,660`S9E8`>8XV
MEH,V`2<3E.D!D]DI`#-D-`&S_^\`OI;^EK//@P"SQ;\`LW3F`/F-KI:3W[0!
MDY54`+/E]0'YC;."M@"#-H$GDQ7I`1-9*0"SY24!L_/C`+Z6GI:S0[0`,\;#
M`+/_X@!YCI/3OP&REA.67P`S9G8`LI8#-@$HDY/D`8F`L^.3`+*7,\9U`/J7
M>8PS1E8`^8YYCJ*7LI<3W[8!$Y96`#-FY@&RE_F/'.&3E^\!D]\O`+/G]P&:
MEL*7QI/VE?F.^8^S\^,`^8T<Z13E(SQU``SQ`S>!*(,W#@"YCP%'F</OT)_"
M@S"!*P,T`2N#-($J`SD!*H,Y@2D#.@$I$P$!+(*`01$3!0`(!N3OT/^:-R=%
M9Q,'%S`8X1='```#-P=+&.4W=UU,!@<3!^?/&.DW5S(0$P=G1QCM-W?I808'
M$P<''QCQ(S0%`B,X!0(C+`4&HF!!`8*`.7$B^";T2O`&_$[L4NA6Y%K@&'63
M%S8`JH2ZEX(7@9,NA#*)8_7G`!AY!0<8^9STG'@35]D!J%RZEYSX$XJ$`S')
MDPD`!+N'J4"^B6-4^0";"0D`4I5C=X4`LP<U`6-Y]``"D+,'-`%C=*0`XVOU
M_DZ&HH7OT/^PO%P[AS<!N-R3!P`$8QOW`B:%.PDY04Z4[^#_X9,*\`,3BX0'
M8\DJ`V-_B@2S!RH!XVWT^DJ&HH52A>_0'ZTCK"0'XG!"=*)T`GGB:4)JHFH"
M:R%A@H"3"00$8W&*`N-F9/FBA1,&``12A>_0'ZHFA4Z$&PD)_._@']QMM^-S
M1/_C<3K_G;?C=T3[LP<D`>-S^OJAOSEQ(O@F]$KP3NQ:X`;\4NA6Y(/7A0(#
MNH4"$XN%`QN7AP"3V8<`@]<%`[/IZ0`3!@#X&Y>'`!/9AP"35SH`D_?W`S-I
MZ0"3AA<`&X<7`-J7@[H%`\(90ADC@,<`DP>``ZJ$+H23V0D#$UD)`S,%VP!C
MW]<.$P8`!!F>@47OT*_Z(H7OX!_2$P:``X%%6H7OT(_YD]>*`2,(]`:3V@H!
MDU>*`1-:"@&C"%0'(QDD!R,*]`:C"D0'(QLT!R*%[^!_SAQ@(H7A@R.`]``<
M8,&#HX#T`!Q@H8,C@?0`'&"C@?0`'&3A@R."]``<9,&#HX+T`!QDH8,C@_0`
M'&2C@_0`'&CA@R.$]``<:,&#HX3T`!QHH8,CA?0`'&BCA?0`'&SA@R.&]``<
M;,&#HX;T`!QLH8,CA_0`'&RCA_0`''#A@R.(]``<<,&#HXCT`!QPH8,CB?0`
M''"CB?0`0G3B<*)T`GGB:4)JHFH":R%A;]#?BQ,&@`,9GH%%(;\````````N
M`````````"XN````````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R
M;V,O)6DO)7,``````%!!4E]414U0``````````!005)?4%)/1TY!344`````
M.@`````````O`````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,
M24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'````````
M`%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?
M1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````#$`````````3$1?3$E"
M4D%265]0051(`%-94U1%30``+W1M<`````!54T52`````%5315).04U%````
M```````E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*````````4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S
M)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8
M`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@``
M```Q+C`U-P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````
M```````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM````
M````5$U01$E2``!414U01$E2`%1%35``````5$U0``````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?
M<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)
M3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE
M7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U
M8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*
M;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE
M.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S
M:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E
M860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#
M*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@
M,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP
M(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F
M:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M
M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS
M>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!
M1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@
M*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG
M="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@
M)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]
M"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M
M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I
M;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA
M9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F
M("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F
M;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D
M8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I
M>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F
M<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@
M,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q
M=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR
M971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL
M97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I
M('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F
M('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!
M1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*
M)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII
M9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(
M+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@
M(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC
M;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ
M<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=
M.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%
M04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*
M)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE
M("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*
M;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M
M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O
M=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A
M<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I
M;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN
M+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X
M=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T
M:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[
M4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@
M>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M
M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A
M8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@
M(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I
M<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH
M;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D
M8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE
M?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[
M7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E
M;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,
M3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*``````!P97)L>'-I+F,``````````$-!0TA%``")J\WO
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````0````````#V`@````````$`````
M`````0,````````/`````````%@$````````#`````````````````````T`
M```````````````````9`````````!">````````&P`````````(````````
M`!H`````````&)X````````<``````````@`````````]?[_;P`````@`@``
M``````4`````````D`P````````&```````````#````````"@````````!V
M!`````````L`````````&``````````5`````````````````````P``````
M``!0H`````````(`````````0`4````````4``````````<`````````%P``
M``````!@$P````````<`````````"!$````````(`````````)@'````````
M"0`````````8`````````!X`````````&`````````#[__]O``````$```@`
M````^?__;P`````*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````*4$%2+G!M"@``````````````````````````
M``````````````````````````````````````````````````````````#_
M_________P``````````H!@```````"@&````````*`8````````H!@`````
M``"@&````````*`8````````H!@```````"@&````````*`8````````H!@`
M``````"@&````````*`8````````H!@```````"@&````````*`8````````
MH!@```````"@&````````*`8````````H!@```````"@&````````*`8````
M````H!@```````"@&````````*`8````````H!@```````"@&````````*`8
M````````H!@```````"@&````````*`8````````H!@```````"@&```````
M`*`8````````H!@```````"@&````````*`8````````H!@```````"@&```
M`````*`8````````H!@```````"@&````````*`8````````H!@```````"@
M&````````*`8````````H!@```````"@&````````*`8````````H!@`````
M``"@&````````*`8````````H!@```````"@&````````*`8````````H!@`
M``````"@&````````"">````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'0T,Z("A!;'!I;F4@,3(N,BXQ7V=I=#(P,C(P.3(T
M+7(T*2`Q,BXR+C$@,C`R,C`Y,C0`04D```!R:7-C=@`!/P````00!7)V-C1I
M,G`Q7VTR<#!?83)P,5]F,G`R7V0R<#)?8S)P,%]Z:6-S<C)P,%]Z:69E;F-E
M:3)P,```+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YG
M;W0`+F)S<P`N8V]M;65N=``N<FES8W8N871T<FEB=71E<P``````````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(```````````(``````````@``````
M`!H````````````````````!````````````````````$P```/;__V\"````
M`````"`"````````(`(```````#<``````````,`````````"```````````
M`````````!T````+`````@```````````P`````````#````````D`D`````
M```$`````@````@`````````&``````````E`````P````(`````````D`P`
M``````"0#````````'8$```````````````````!````````````````````
M+0````0````"``````````@1````````"!$```````!8`@````````,`````
M````"``````````8`````````#<````$````0@````````!@$P```````&`3
M````````0`4````````#````#P````@`````````&``````````\`````0``
M``8`````````H!@```````"@&````````*`#```````````````````0````
M`````!``````````00````$````&`````````$`<````````0!P```````"R
M)@```````````````````@```````````````````$<````!`````@``````
M``#X0@```````/A"````````\$$```````````````````@`````````````
M``````!/`````0````(`````````Z(0```````#HA`````````0`````````
M```````````$````````````````````60````X````#`````````!">````
M````$(X````````(````````````````````"``````````(`````````&4`
M```/`````P`````````8G@```````!B.````````"```````````````````
M``@`````````"`````````!Q````!@````,`````````()X````````@C@``
M`````.`!````````!``````````(`````````!``````````>@````$````#
M``````````"@`````````)````````!0````````````````````"```````
M`````````````(`````!`````P````````!0H````````%"0````````6`(`
M``````````````````@`````````"`````````"%````"`````,`````````
MJ*(```````"HD@```````%@````````````````````(````````````````
M````B@````$````P````````````````````J)(````````T````````````
M`````````0`````````!`````````),````#``!P````````````````````
M`-R2````````2@````````````````````$````````````````````!````
M`P`````````````````````````FDP```````*4````````````````````!
/````````````````````
